{ config, lib, modulesPath, ... }:

{
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
  ];

  boot = {
    initrd = {
      availableKernelModules = [ "xhci_pci" "sdhci_pci" ];
      kernelModules = [ "dm-snapshot" ];
    };
    kernelModules = [ "kvm-intel" ];
  };

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/e8c9c5a8-4df0-4100-8de6-f08a1a774fad";
      fsType = "btrfs";
      options = [ "subvol=@" "noatime" "nodiratime" "discard" ];
    };
    "/nix" = {
      device = "/dev/disk/by-uuid/e8c9c5a8-4df0-4100-8de6-f08a1a774fad";
      fsType = "btrfs";
      options = [ "subvol=@nix" "noatime" "nodiratime" "discard" ];
    };
    "/var" = {
      device = "/dev/disk/by-uuid/e8c9c5a8-4df0-4100-8de6-f08a1a774fad";
      fsType = "btrfs";
      options = [ "subvol=@var" "noatime" "nodiratime" "discard" ];
    };
    "/.snapshots" = {
      device = "/dev/disk/by-uuid/e8c9c5a8-4df0-4100-8de6-f08a1a774fad";
      fsType = "btrfs";
      options = [ "subvol=@snapshots" "noatime" "nodiratime" "discard" ];
    };
    "/home" = {
      device = "/dev/disk/by-uuid/e8c9c5a8-4df0-4100-8de6-f08a1a774fad";
      fsType = "btrfs";
      options = [ "subvol=@home" "noatime" "nodiratime" "discard" ];
    };
    "/boot" = {
      device = "/dev/disk/by-uuid/1C76-1006";
      fsType = "vfat";
      options = [ "fmask=0022" "dmask=0022" ];
    };

    # Remote
    "/home/jimbo/JimboNFS" = {
      device = "${config.ips.wgSpan}.1:/export/JimboNFS";
      fsType = "nfs4";
      options = [ "x-systemd.automount" "_netdev" "nofail" "noauto" ];
    };
  };

  swapDevices = [
    { device = "/dev/disk/by-uuid/54a9cc22-4a2c-4e04-a968-313c34481489"; }
  ];

  networking.useDHCP = lib.mkDefault true;
  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  hardware.cpu.intel.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
